Struct PublicKey

pub struct PublicKey {
    pub public_key: WithContext<PublicKey>,
    pub galois_key: Option<WithContext<GaloisKeys>>,
    pub relin_key: Option<WithContext<RelinearizationKeys>>,
}
A bundle of public keys. These may be freely shared with other parties without risk of compromising data security.

Remarks

In traditional asymmetric cryptography (e.g. RSA, ECC), schemes contain only public and private keys. The public key is used for encryption and the private key is used to decrypt data.

In addition to the tradtional public key, homomorphic cryptographic schemes may have additional keys to facilitate certain homomorphic operations. These keys are “public” in the sense that they may be freely shared without compromising data privacy, but they are generally used for operations other than encryption. For example, RelinearizationKeys are used in the BFV and CKKS schemes to reduce noise growth and prevent ciphertext size growth after multiplication.

Fields

public_key: WithContext<PublicKey>

The public key used for encryption operations.

galois_key: Option<WithContext<GaloisKeys>>

Galois keys are used in BFV and CKKS schemes to rotate Batched vectors.

FhePrograms that don’t feature rotations have no use for these keys.

relin_key: Option<WithContext<RelinearizationKeys>>

Relinearization keys are used in the BFV and CKKS schemes during relinearization operations. Relinearization reduces noise growth and prevents ciphertext size growth resulting from multiplication. Sunscreen automatically inserts relinearization operations, and hence they are an implementation detail.

FhePrograms without multiplications don’t have relinearizations and thus don’t need these keys.